@@ -305,6 +305,11 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         { MENU_GO, NULL, _("_Go"), NULL, NULL, NULL },
 
         { MENU_HELP,                NULL,                   _("_Help"),                             NULL,         NULL,                                 NULL },
+/* TODO: Link to help.gnome.org, or locally-installed help, on Windows. */
+#ifndef G_OS_WIN32
+        { AM_OPEN_HELP_CONTENTS, GTK_STOCK_HELP, _("_Contents"), "F1",
+          _("Show help"), G_CALLBACK (et_show_help) },
+#endif
         { AM_OPEN_ABOUT_WINDOW,     GTK_STOCK_ABOUT,        _("_About"),                            NULL,         _("About"),                           G_CALLBACK(Show_About_Window) },
 
 
@@ -430,7 +435,6 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
     gtk_widget_show_all(menubar);
 
     toolbar = gtk_ui_manager_get_widget (UIManager, "/ToolBar");
-    gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
     gtk_widget_show_all(toolbar);
 
     *pptoolbar = toolbar;
@@ -538,13 +542,20 @@ Statusbar_Stop_Timer (void)
     return G_SOURCE_REMOVE;
 }
 
+static void
+et_statusbar_reset_timer (void)
+{
+    StatusbarTimerId = 0;
+}
+
 static void
 Statusbar_Start_Timer (void)
 {
     Statusbar_Remove_Timer ();
-    StatusbarTimerId = g_timeout_add_seconds (4,
-                                              (GSourceFunc)Statusbar_Stop_Timer,
-                                              NULL);
+    StatusbarTimerId = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, 4,
+                                                   (GSourceFunc)Statusbar_Stop_Timer,
+                                                   NULL,
+                                                   (GDestroyNotify)et_statusbar_reset_timer);
     g_source_set_name_by_id (StatusbarTimerId, "Statusbar stop timer");
 }
 
@@ -555,7 +566,7 @@ Statusbar_Remove_Timer (void)
     {
         Statusbar_Stop_Timer ();
         g_source_remove(StatusbarTimerId);
-        StatusbarTimerId = 0;
+        et_statusbar_reset_timer ();
     }
 }
 
