@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  */
 
@@ -25,7 +25,7 @@
 #include <glib.h>
 #include <string.h>
 #include <errno.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 
 #ifdef HAVE_LANGINFO_CODESET
 #include <langinfo.h>
@@ -35,9 +35,7 @@
 #include "setting.h"
 #include "log.h"
 
-#ifdef G_OS_WIN32
 #include "win32/win32dep.h"
-#endif /* G_OS_WIN32 */
 
 
 /****************
@@ -159,7 +157,7 @@ check_locale (const char *locale)
 }
 
 /* stolen from gnome-desktop-item.c */
-static void
+G_GNUC_NULL_TERMINATED static void
 insert_locales (GHashTable *encodings, char *enc, ...)
 {
     va_list args;
@@ -254,8 +252,7 @@ get_encoding_from_locale (const char *locale)
     char lang[3];
     const char *encoding;
 
-    if (locale == NULL)
-        return NULL;
+    g_return_val_if_fail (locale != NULL, NULL);
 
     /* if locale includes encoding, use it *//*
     encoding = strchr (locale, '.');
@@ -445,8 +442,7 @@ gchar *convert_to_utf8 (const gchar *string)
     gchar *output;
     GError *error = NULL;
 
-    if (!string)
-        return NULL;
+    g_return_val_if_fail (string != NULL, NULL);
 
     output = g_locale_to_utf8(string, -1, NULL, NULL, &error);
 
@@ -645,8 +641,7 @@ gchar *Try_To_Validate_Utf8_String (const gchar *string)
     gchar *ret = NULL;
     GError *error = NULL;
 
-    if (!string)
-        return NULL;
+    g_return_val_if_fail (string != NULL, NULL);
 
     if (g_utf8_validate(string, -1, NULL))
     {
