@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -32,21 +32,6 @@
  * Declaration *
  ***************/
 
-#ifndef MAX
-#    define MAX(a,b)      ((a) > (b) ? (a) : (b))
-#endif
-
-#ifndef MIN
-#    define MIN(a,b)      ((a) < (b) ? (a) : (b))
-#endif
-#ifndef MIN3
-#    define MIN3(x,y,z)   (MIN(x,y) < (z) ? MIN(x,y) : (z))
-#endif
-#ifndef MIN4
-#    define MIN4(x,y,z,w) (MIN3(x,y,z) < (w) ? MIN3(x,y,z) : (w))
-#endif
-
-
 /*
  * Colors Used (see declaration into et_core.c)
  */
@@ -66,10 +51,6 @@ typedef enum
 {
     SORTING_BY_ASCENDING_FILENAME,
     SORTING_BY_DESCENDING_FILENAME,
-    SORTING_BY_ASCENDING_TRACK_NUMBER,
-    SORTING_BY_DESCENDING_TRACK_NUMBER,
-    SORTING_BY_ASCENDING_CREATION_DATE,
-    SORTING_BY_DESCENDING_CREATION_DATE,
     SORTING_BY_ASCENDING_TITLE,
     SORTING_BY_DESCENDING_TITLE,
     SORTING_BY_ASCENDING_ARTIST,
@@ -80,6 +61,10 @@ typedef enum
     SORTING_BY_DESCENDING_ALBUM,
     SORTING_BY_ASCENDING_YEAR,
     SORTING_BY_DESCENDING_YEAR,
+    SORTING_BY_ASCENDING_DISC_NUMBER,
+    SORTING_BY_DESCENDING_DISC_NUMBER,
+    SORTING_BY_ASCENDING_TRACK_NUMBER,
+    SORTING_BY_DESCENDING_TRACK_NUMBER,
     SORTING_BY_ASCENDING_GENRE,
     SORTING_BY_DESCENDING_GENRE,
     SORTING_BY_ASCENDING_COMMENT,
@@ -94,6 +79,8 @@ typedef enum
     SORTING_BY_DESCENDING_URL,
     SORTING_BY_ASCENDING_ENCODED_BY,
     SORTING_BY_DESCENDING_ENCODED_BY,
+    SORTING_BY_ASCENDING_CREATION_DATE,
+    SORTING_BY_DESCENDING_CREATION_DATE,
     SORTING_BY_ASCENDING_FILE_TYPE,
     SORTING_BY_DESCENDING_FILE_TYPE,
     SORTING_BY_ASCENDING_FILE_SIZE,
@@ -186,6 +173,7 @@ struct _File_Tag
     gchar *album_artist;   /* Album Artist */
     gchar *album;          /* Album name */
     gchar *disc_number;    /* Disc number */
+    gchar *disc_total; /* The total number of discs of the album (ex: 1/2). */
     gchar *year;           /* Year of track */
     gchar *track;          /* Position of track in the album */
     gchar *track_total;    /* The number of tracks for the album (ex: 12/20) */
@@ -215,7 +203,7 @@ struct _ET_File_Info
     gboolean variable_bitrate;  /* Is a VBR file? */
     gint samplerate;            /* Samplerate (Hz) */
     gint mode;                  /* Stereo, ... or channels for ogg */
-    gint size;                  /* The size of file (in bytes) */
+    goffset size;               /* The size of file (in bytes) */
     gint duration;              /* The duration of file (in seconds) */
     gchar *mpc_profile;         /* MPC data */
     gchar *mpc_version;         /* MPC data : encoder version  (also for Speex) */
@@ -294,7 +282,7 @@ struct _ET_File
 
     GList *FileNameCur;       /* Points to item of FileNameList that represents the current value of filename state (i.e. file on hard disk) */
     GList *FileNameNew;       /* Points to item of FileNameList that represents the new value of filename state */
-    GList *FileNameList;      /* Contains the history of changes about the file name */
+    GList *FileNameList; /* Contains the history of changes about the filename. */
     GList *FileNameListBak;   /* Contains items of FileNameList removed by 'undo' procedure but have data currently saved (for example, when you save your last changes, make some 'undo', then make new changes) */
     
     GList *FileTag;           /* Points to the current item used of FileTagList */
@@ -416,6 +404,10 @@ gint ET_Comp_Func_Sort_File_By_Ascending_Filename         (ET_File *ETFile1, ET_
 gint ET_Comp_Func_Sort_File_By_Descending_Filename        (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Ascending_Creation_Date    (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Descending_Creation_Date   (ET_File *ETFile1, ET_File *ETFile2);
+gint et_comp_func_sort_file_by_ascending_disc_number (ET_File *ETFile1,
+                                                      ET_File *ETFile2);
+gint et_comp_func_sort_file_by_descending_disc_number (ET_File *ETFile1,
+                                                       ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Ascending_Track_Number     (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Descending_Track_Number    (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Ascending_Title            (ET_File *ETFile1, ET_File *ETFile2);
