@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include <string.h>
@@ -138,8 +138,7 @@ libapetag_maloc_cont_int (apetag *mem_cnt, struct tag *mTag)
     struct tag **tag_tmp = mem_cnt->tag;
 
     if (mem_cnt->memTagAlloc == 0) {    /* init */
-        mem_cnt->tag = (struct tag **)
-            malloc (((sizeof (struct tag **)) * (LIBAPETAG_MEM_ALLOC_AHEAD)));
+        mem_cnt->tag = (struct tag **) malloc ((sizeof (struct tag *) * LIBAPETAG_MEM_ALLOC_AHEAD));
         mem_cnt->memTagAlloc = LIBAPETAG_MEM_ALLOC_AHEAD;
         mem_cnt->countTag = 0;
         if (mem_cnt->tag == NULL) {
@@ -150,7 +149,7 @@ libapetag_maloc_cont_int (apetag *mem_cnt, struct tag *mTag)
     }
     
     if ((mem_cnt->memTagAlloc) <= (mem_cnt->countTag + 1)) {
-        mem_cnt->tag = (struct tag **) realloc (mem_cnt->tag, ((sizeof (struct tag **)) *
+        mem_cnt->tag = (struct tag **) realloc (mem_cnt->tag, (sizeof (struct tag *) *
                         (mem_cnt->memTagAlloc + LIBAPETAG_MEM_ALLOC_AHEAD)));
         mem_cnt->memTagAlloc += LIBAPETAG_MEM_ALLOC_AHEAD;
     }
@@ -916,7 +915,13 @@ apetag_save (char *filename, apetag *mem_cnt, int flag)
     
     if (id3v1) {
         fseek (fp, -128, SEEK_END);
-        fread (&id3v1_tag, 1, sizeof (struct _id3v1Tag), fp);
+        if (fread (&id3v1_tag, 1, sizeof (struct _id3v1Tag), fp)
+            != sizeof (struct _id3v1Tag))
+        {
+            PRINT_ERR ("ERROR->apetaglib->apetag_save::fread");
+            fclose (fp);
+            return ATL_FREAD;
+        }
         skipBytes += id3v1;
     }
     skipBytes += apeTag;
@@ -1033,7 +1038,10 @@ apetag_save (char *filename, apetag *mem_cnt, int flag)
         fflush (fp);
         fclose (fp);
         /* ftruncate don't work */ 
-        truncate (filename, newFileSize);
+        if (truncate (filename, newFileSize) == -1)
+        {
+            PRINT_ERR ("FATAL_ERROR->libapetag->apetag_save::fwrite [file not truncated]");
+        }
     } else { /* !!SAVE_FAKE_SAVE */
         libapetag_print_mem_cnt (mem_cnt);
     }
