@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -48,7 +48,8 @@ GtkWidget *Create_Log_Area      (void);
 
 void       Log_Clean_Log_List   (void);
 
-void       Log_Print            (Log_Error_Type error_type, gchar const *format, ...);
+void Log_Print (Log_Error_Type error_type,
+                gchar const *format, ...) G_GNUC_PRINTF (2, 3);
 
 
 #endif /* __LOG_H__ */
