@@ -80,14 +80,16 @@ void Run_Audio_Player_Using_Selection (void);
 void Run_Audio_Player_Using_Browser_Artist_List (void);
 void Run_Audio_Player_Using_Browser_Album_List  (void);
 
-gchar *Convert_Size (gsize size);
-gchar *Convert_Size_1 (gsize size);
 gchar *Convert_Duration (gulong duration);
 
-off_t Get_File_Size (const gchar *filename);
+void et_show_help (void);
+
+goffset et_get_file_size (const gchar *filename);
 
 gint Combo_Alphabetic_Sort (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data);
 
+gboolean et_run_program (const gchar *program_name, GList *args_list);
+
 void File_Selection_Window_For_File      (GtkWidget *entry);
 void File_Selection_Window_For_Directory (GtkWidget *entry);
 
@@ -106,4 +108,6 @@ void Load_Filename_Window_Apply_Changes (void);
 gchar * et_disc_number_to_string (const guint disc_number);
 gchar * et_track_number_to_string (const guint track_number);
 
+void et_on_child_exited (GPid pid, gint status, gpointer user_data);
+
 #endif /* __MISC_H__ */
