@@ -54,7 +54,7 @@ gboolean Mp4_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     g_return_val_if_fail (filename != NULL && ETFileInfo != NULL, FALSE);
 
     /* Get size of file */
-    ETFileInfo->size = Get_File_Size(filename);
+    ETFileInfo->size = et_get_file_size (filename);
 
     if ((file = taglib_file_new_type(filename, TagLib_File_MP4)) == NULL )
     {
@@ -151,8 +151,8 @@ gboolean Mp4_Header_Display_File_Info_To_UI(gchar *filename, ET_File_Info *ETFil
     g_free(text);
 
     /* Size */
-    size  = Convert_Size(ETFileInfo->size);
-    size1 = Convert_Size(ETCore->ETFileDisplayedList_TotalSize);
+    size  = g_format_size (ETFileInfo->size);
+    size1 = g_format_size (ETCore->ETFileDisplayedList_TotalSize);
     text  = g_strdup_printf("%s (%s)",size,size1);
     gtk_label_set_text(GTK_LABEL(SizeValueLabel),text);
     if (size)  g_free(size);
