@@ -15,15 +15,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <config.h> // For definition of ENABLE_OGG
+#include "config.h" // For definition of ENABLE_OGG
 
 #ifdef ENABLE_OGG
 
 #include <gtk/gtk.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -42,10 +42,8 @@
 #include "setting.h"
 #include "charset.h"
 
-#ifdef G_OS_WIN32
-// for mkstemp
+/* for mkstemp. */
 #include "win32/win32dep.h"
-#endif /* G_OS_WIN32 */
 
 
 /***************
@@ -107,7 +105,6 @@
 /**************
  * Prototypes *
  **************/
-static gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *state);
 
 static gboolean Ogg_Write_Delimetered_Tag (vorbis_comment *vc, const gchar *tag_name, gchar *values);
 static gboolean Ogg_Write_Tag (vorbis_comment *vc, const gchar *tag_name, gchar *value);
@@ -122,9 +119,11 @@ static void Ogg_Set_Tag (vorbis_comment *vc, const gchar *tag_name, gchar *value
  * Note:
  *  - if field is found but contains no info (strlen(str)==0), we don't read it
  */
-gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
+gboolean
+ogg_tag_read_file_tag (gchar *filename, File_Tag *FileTag, GError **error)
 {
-    FILE           *file;
+    GFile *file;
+    GFileInputStream *istream;
     vcedit_state   *state;
     vorbis_comment *vc;
     gchar          *string = NULL;
@@ -134,16 +133,16 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     guint           field_num, i;
     Picture        *prev_pic = NULL;
 
+    g_return_val_if_fail (filename != NULL && FileTag != NULL, FALSE);
+    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-    if (!filename || !FileTag)
-        return FALSE;
+    file = g_file_new_for_path (filename);
+    istream = g_file_read (file, NULL, error);
 
-    ogg_error_msg = NULL;
-
-    if ( (file=fopen(filename,"rb")) == NULL )
+    if (!istream)
     {
-        Log_Print(LOG_ERROR,_("Error while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
-        g_free(filename_utf8);
+        g_object_unref (file);
+        g_assert (error == NULL || *error != NULL);
         return FALSE;
     }
 
@@ -153,45 +152,76 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     gulong id3v2size;
 
     // Check if there is an ID3v2 tag...
-    fseek(file, 0L, SEEK_SET);
-    if (fread(tmp_id3, 1, 4, file) == 4)
+    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
+    {
+        goto err;
+    }
+
+    if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4, NULL,
+                             error) == 4)
     {
         // Calculate ID3v2 length
         if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
         {
             // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
-            fseek(file, 2, SEEK_CUR); // Size is 6-9 position
-            if (fread(tmp_id3, 1, 4, file) == 4)
+            /* Size is 6-9 position */
+            if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
+                                  NULL, error))
+            {
+                goto err;
+            }
+
+            if (g_input_stream_read (G_INPUT_STREAM (istream), tmp_id3, 4,
+                                     NULL, error) == 4)
             {
                 id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
                                 | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
-                fseek(file, id3v2size, SEEK_SET);
+
+                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
+                                      G_SEEK_SET, NULL, error))
+                {
+                    goto err;
+                }
+
                 Log_Print(LOG_ERROR,_("Warning: The Ogg Vorbis file '%s' contains an ID3v2 tag."),filename_utf8);
-            }else
-            {
-                fseek(file, 0L, SEEK_SET);
             }
-        }else
-        {
-            fseek(file, 0L, SEEK_SET);
+            else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
+                                       NULL, error))
+            {
+                goto err;
+            }
+
         }
-    }else
-    {
-        fseek(file, 0L, SEEK_SET);
+        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
+                                   NULL, error))
+        {
+            goto err;
+        }
+
     }
+    else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
+                               NULL, error))
+    {
+        goto err;
     }
 
+    }
+
+    g_assert (error == NULL || *error == NULL);
+
+    g_object_unref (istream);
+
     state = vcedit_new_state();    // Allocate memory for 'state'
-    if ( vcedit_open(state,file) < 0 )
+
+    if (!vcedit_open (state, file, error))
     {
-        Log_Print(LOG_ERROR,_("Error: Failed to open file: '%s' as Vorbis (%s)."),filename_utf8,vcedit_error(state));
-        ogg_error_msg = vcedit_error(state);
-        fclose(file);
-        g_free(filename_utf8);
+        g_assert (error == NULL || *error != NULL);
+        g_object_unref (file);
         vcedit_clear(state);
         return FALSE;
     }
 
+    g_assert (error == NULL || *error == NULL);
 
     /* Get data from tag */
     vc = vcedit_comments(state);
@@ -279,12 +309,32 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         g_free(string);
     }
 
-    /*******************************
-     * Disc Number (Part of a Set) *
-     *******************************/
-    if ( (string = vorbis_comment_query(vc,"DISCNUMBER",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
+    /**********************************************
+     * Disc Number (Part of a Set) and Disc Total *
+     **********************************************/
+    if ((string = vorbis_comment_query (vc, "DISCNUMBER", 0)) != NULL
+        && g_utf8_strlen (string, -1) > 0)
     {
-        FileTag->disc_number = g_strdup(string);
+        FileTag->disc_number = g_strdup (string);
+    }
+
+    if ((string = vorbis_comment_query (vc, "DISCNUMBER", 0)) != NULL
+        && g_utf8_strlen (string, -1) > 0)
+    {
+        /* Check if DISCTOTAL used, else takes it in DISCNUMBER. */
+        if ((string1 = vorbis_comment_query (vc, "DISCTOTAL", 0)) != NULL
+            && g_utf8_strlen (string1, -1) > 0)
+        {
+            FileTag->disc_total = et_disc_number_to_string (atoi (string1));
+        }
+        else if ((string1 = g_utf8_strchr (string, -1, '/')))
+        {
+            FileTag->disc_total = et_disc_number_to_string (atoi (string1
+                                                                  + 1));
+            *string1 = '\0';
+        }
+
+        FileTag->disc_number = et_disc_number_to_string (atoi (string));
     }
 
     /********
@@ -302,33 +352,19 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      *************************/
     if ( (string = vorbis_comment_query(vc,"TRACKNUMBER",0)) != NULL && g_utf8_strlen(string, -1) > 0 )
     {
-        if (NUMBER_TRACK_FORMATED)
+        /* Check if TRACKTOTAL used, else takes it in TRACKNUMBER. */
+        if ((string1 = vorbis_comment_query (vc, "TRACKTOTAL", 0)) != NULL
+            && g_utf8_strlen (string1, -1) > 0)
         {
-            // Ckeck if TRACKTOTAL used, else takes it in TRACKNUMBER
-            if ( (string1 = vorbis_comment_query(vc,"TRACKTOTAL",0)) != NULL && g_utf8_strlen(string1, -1) > 0 )
-            {
-                FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string1));
-            }else
-            if ( (string1 = g_utf8_strchr(string, -1, '/')) )
-            {
-                FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string1+1));
-                *string1 = '\0';
-            }
-            FileTag->track = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string));
-        }else
-        {
-            // Ckeck if TRACKTOTAL used, else takes it in TRACKNUMBER
-            if ( (string1 = vorbis_comment_query(vc,"TRACKTOTAL",0)) != NULL && g_utf8_strlen(string1, -1) > 0 )
-            {
-                FileTag->track_total = g_strdup_printf("%.*d",NUMBER_TRACK_FORMATED_SPIN_BUTTON,atoi(string1));
-            }else
-            if ( (string1 = g_utf8_strchr(string, -1, '/')) )
-            {
-                FileTag->track_total = g_strdup(string1+1);
-                *string1 = '\0';
-            }
-            FileTag->track = g_strdup(string);
+            FileTag->track_total = et_track_number_to_string (atoi (string1));
         }
+        else if ((string1 = g_utf8_strchr (string, -1, '/')))
+        {
+            FileTag->track_total = et_track_number_to_string (atoi (string1
+                                                                    + 1));
+            *string1 = '\0';
+        }
+        FileTag->track = g_strdup (string);
     }
 
     /*********
@@ -463,7 +499,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      * URL *
      *******/
     field_num = 0;
-    while ( (string = vorbis_comment_query(vc,"LICENSE",field_num++)) != NULL )
+    while ((string = vorbis_comment_query (vc, "CONTACT", field_num++)) != NULL)
     {
         string = Try_To_Validate_Utf8_String(string);
 
@@ -562,7 +598,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp(vc->user_comments[i],"COMPOSER=",         9) != 0
           && strncasecmp(vc->user_comments[i],"PERFORMER=",       10) != 0
           && strncasecmp(vc->user_comments[i],"COPYRIGHT=",       10) != 0
-          && strncasecmp(vc->user_comments[i],"LICENSE=",          8) != 0
+          && strncasecmp(vc->user_comments[i],"CONTACT=",          8) != 0
           && strncasecmp(vc->user_comments[i],"ENCODED-BY=",      11) != 0
           && strncasecmp(vc->user_comments[i],"COVERART=",         9) != 0
           && strncasecmp(vc->user_comments[i],"COVERARTTYPE=",       13) != 0
@@ -576,10 +612,18 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     }
 
     vcedit_clear(state);
-    fclose(file);
+    g_object_unref (file);
     g_free(filename_utf8);
 
     return TRUE;
+
+err:
+    g_assert (error == NULL || *error != NULL);
+    g_object_unref (istream);
+    g_object_unref (istream);
+    g_object_unref (file);
+    g_free(filename_utf8);
+    return FALSE;
 }
 
 
@@ -623,77 +667,117 @@ static void Ogg_Set_Tag (vorbis_comment *vc, const gchar *tag_name, gchar *value
     }
 }
 
-gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
+gboolean
+ogg_tag_write_file_tag (ET_File *ETFile, GError **error)
 {
     File_Tag       *FileTag;
     gchar          *filename;
     gchar          *filename_utf8;
     gchar          *basename_utf8;
-    FILE           *file_in;
+    GFile           *file;
+    GFileInputStream *istream;
     vcedit_state   *state;
     vorbis_comment *vc;
     gchar          *string;
     GList          *list;
     Picture        *pic;
 
-    if (!ETFile || !ETFile->FileTag)
-        return FALSE;
+    g_return_val_if_fail (ETFile != NULL && ETFile->FileTag != NULL, FALSE);
+    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
     FileTag       = (File_Tag *)ETFile->FileTag->data;
     filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
     filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
-    ogg_error_msg = NULL;
 
-    /* Test to know if we can write into the file */
-    if ( (file_in=fopen(filename,"rb"))==NULL )
+    file = g_file_new_for_path (filename);
+    istream = g_file_read (file, NULL, error);
+
+    if (!istream)
     {
-        Log_Print(LOG_ERROR,_("Error while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
+        g_object_unref (file);
         return FALSE;
     }
 
     {
     // Skip the id3v2 tag
+    gsize bytes_read;
     guchar tmp_id3[4];
     gulong id3v2size;
 
     // Check if there is an ID3v2 tag...
-    fseek(file_in, 0L, SEEK_SET);
-    if (fread(tmp_id3, 1, 4, file_in) == 4)
+    if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET, NULL, error))
+    {
+        goto err;
+    }
+
+    if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
+                                 &bytes_read, NULL, error))
     {
         // Calculate ID3v2 length
         if (tmp_id3[0] == 'I' && tmp_id3[1] == 'D' && tmp_id3[2] == '3' && tmp_id3[3] < 0xFF)
         {
             // id3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
-            fseek(file_in, 2, SEEK_CUR); // Size is 6-9 position
-            if (fread(tmp_id3, 1, 4, file_in) == 4)
+            /* Size is 6-9 position */
+            if (!g_seekable_seek (G_SEEKABLE (istream), 2, G_SEEK_CUR,
+                                  NULL, error))
+            {
+                goto err;
+            }
+
+            if (g_input_stream_read_all (G_INPUT_STREAM (istream), tmp_id3, 4,
+                                         &bytes_read, NULL, error))
             {
                 id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
                                 | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
-                fseek(file_in, id3v2size, SEEK_SET);
-            }else
-            {
-                fseek(file_in, 0L, SEEK_SET);
+
+                if (!g_seekable_seek (G_SEEKABLE (istream), id3v2size,
+                                      G_SEEK_SET, NULL, error))
+                {
+                    goto err;
+                }
+
+                Log_Print(LOG_ERROR,_("Warning: The Ogg Vorbis file '%s' contains an ID3v2 tag."),filename_utf8);
             }
-        }else
-        {
-            fseek(file_in, 0L, SEEK_SET);
+            else
+            {
+                g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of "
+                         "data were read", bytes_read);
+                goto err;
+            }
+
         }
-    }else
-    {
-        fseek(file_in, 0L, SEEK_SET);
+        else if (!g_seekable_seek (G_SEEKABLE (istream), 0L, G_SEEK_SET,
+                                   NULL, error))
+        {
+            goto err;
+        }
+
     }
+    else
+    {
+        g_debug ("Only %" G_GSIZE_FORMAT " bytes out of 4 bytes of data were "
+                 "read", bytes_read);
+        goto err;
     }
 
+    }
+
+    g_assert (error == NULL || *error == NULL);
+
+    g_object_unref (istream);
+
     state = vcedit_new_state();    // Allocate memory for 'state'
-    if ( vcedit_open(state,file_in) < 0 )
+
+    if (!vcedit_open (state, file, error))
     {
-        Log_Print(LOG_ERROR,_("Error: Failed to open file: '%s' as Vorbis (%s)."),filename_utf8,vcedit_error(state));
-        ogg_error_msg = vcedit_error(state);
-        fclose(file_in);
+        g_assert (error == NULL || *error != NULL);
+        g_object_unref (file);
         vcedit_clear(state);
         return FALSE;
     }
 
+    g_assert (error == NULL || *error == NULL);
+
     /* Get data from tag */
     vc = vcedit_comments(state);
     vorbis_comment_clear(vc);
@@ -723,6 +807,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
      * Disc Number *
      ***************/
     Ogg_Set_Tag(vc,"DISCNUMBER=",FileTag->disc_number,FALSE);
+    Ogg_Set_Tag (vc, "DISCTOTAL=", FileTag->disc_total, FALSE);
 
     /********
      * Year *
@@ -744,20 +829,9 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     /***********
      * Comment *
      ***********/
-    // We write the comment using the two formats "DESCRIPTION" and "COMMENT" to be compatible with old versions
-    // Format of new specification
+    /* Format of new specification. */
     Ogg_Set_Tag(vc,"DESCRIPTION=",FileTag->comment,VORBIS_SPLIT_FIELD_COMMENT);
 
-    // Format used in winamp plugin
-    Ogg_Set_Tag(vc,"COMMENT=",FileTag->comment,VORBIS_SPLIT_FIELD_COMMENT);
-
-    if (OGG_TAG_WRITE_XMMS_COMMENT)
-    {
-        // Format used into xmms-1.2.5
-        Ogg_Set_Tag(vc,"=",FileTag->comment,VORBIS_SPLIT_FIELD_COMMENT);
-    }
-
-
     /************
      * Composer *
      ************/
@@ -776,7 +850,7 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     /*******
      * URL *
      *******/
-    Ogg_Set_Tag(vc,"LICENSE=",FileTag->url,FALSE);
+    Ogg_Set_Tag (vc, "CONTACT=", FileTag->url, FALSE);
 
     /**************
      * Encoded by *
@@ -834,93 +908,30 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         list = list->next;
     }
 
-    /* Write tag, and close also 'file_in' in all cases */
-    if ( Ogg_Tag_Write_File(file_in,filename,state) == FALSE )
+    /* Write tag to 'file' in all cases */
+    if (!vcedit_write (state, file, error))
     {
-        ogg_error_msg = vcedit_error(state);
-        Log_Print(LOG_ERROR,_("Error: Failed to write comments to file '%s' (%s)."),filename_utf8,ogg_error_msg == NULL ? "" : ogg_error_msg);
-
+        g_assert (error == NULL || *error != NULL);
+        g_object_unref (file);
         vcedit_clear(state);
         return FALSE;
-    }else
+    }
+    else
     {
         basename_utf8 = g_path_get_basename(filename_utf8);
         Log_Print(LOG_OK,_("Written tag of '%s'"),basename_utf8);
+        g_free (basename_utf8);
 
         vcedit_clear(state);
     }
 
+    g_assert (error == NULL || *error == NULL);
     return TRUE;
+    
+err:
+    g_assert (error == NULL || *error != NULL);
+    g_object_unref (istream);
+    g_object_unref (file);
+    return FALSE;
 }
-
-
-
-/* 
- * Write tag information to a new temporary file, and rename it the the initial name.
- */
-static gboolean
-Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *state)
-{
-    gchar *filename_out;
-    gint   file_mkstemp;
-    FILE  *file_out;
-    gboolean return_code = TRUE;
-
-
-    filename_out = g_strdup_printf("%s.XXXXXX",filename_in);
-    
-    // Function mkstemp() opens also the file!
-    if ((file_mkstemp = mkstemp(filename_out)) < 0)
-    {
-        fclose(file_in);
-        close(file_mkstemp);
-        g_free(filename_out);
-        return FALSE;
-    }
-    close(file_mkstemp);
-    
-    if ( (file_out=fopen(filename_out,"wb")) == NULL )
-    {
-        fclose(file_in);
-        remove(filename_out);
-        g_free(filename_out);
-        return FALSE;
-    }
-    
-    if (vcedit_write(state,file_out) < 0)
-    {
-        fclose(file_in);
-        fclose(file_out);
-        remove(filename_out);
-        g_free(filename_out);
-        return FALSE;
-    }
-    fclose(file_in);
-    fclose(file_out);
-
-    // Some platforms fail to rename a file if the new name already
-    // exists, so we need to remove, then rename...
-    if (rename(filename_out,filename_in))
-    {
-        // Can't rename directly
-        if (remove(filename_in))
-        {
-            // Can't remove file
-            remove(filename_out);
-            return_code = FALSE;
-
-        }else if (rename(filename_out,filename_in)) 
-        {
-            // Can't rename after removing file
-            remove(filename_out);
-            return_code = FALSE;
-        }
-    }
-
-    g_free(filename_out);
-
-    return return_code;
-}
-
-
 #endif /* ENABLE_OGG */
